<?php
/**
* BeeWidget class
*
* This is the parent class for all BeeWidgets
*
*/

class BeeWidget extends WP_Widget
{

    /**
    * BeeWidget constructor
    *
    * @return void
    */
    public function __construct()
    {
        $data = $this->getData();
        parent::__construct(
            $data->widget_id,
            $data->widget_name,
            array(
                'description' => $data->description,
            )
        );
    }


    /**
    * Widget save (update) function
    *
    * @return array $instance
    */
    public function update( $new_instance, $old_instance )
    {
        $instance = array();
        $fields = $this->getFields();

        foreach( $new_instance as $key => $value ) {
            if( isset( $fields->{$key}['nostrip'] ) && $fields->{$key}['nostrip'] ) {
                $instance[$key] = $value;
            }
            else {
                $instance[$key] = strip_tags( $value );
            }
        }

        return $instance;
    }


    /**
    * Show settings template in admin panel
    *
    * @param array $instance
    * @return void
    */
    public function form( $instance )
    {
        $html = '';

        foreach( $this->getFields() as $key => $data ) {
            $data = (object) $data;
            $value = isset( $instance[ $key ] ) ? $instance[ $key ] : ( isset($data->default ) ? $data->default : '' );

            $html.= '<p>';
            $html.= '<label for="' . $this->get_field_id( $key ) . '">' . $data->label . '</label>';
            if( isset($data->note ) && $data->note ) {
                $html.= '<em style="float:right;">' . $data->note . '</em>';
            }

            $template_file = BEE_PATH . "widgets/options/{$data->type}.php";
//             if( !file_exists( $template_file ) ) {
//                 $template_file = webit_sysfile( "widgets/options/blank.php" );
//             }

            ob_start();
            require $template_file;
            $html.= ob_get_clean();

            $html.= '</p>';
        }

        echo $html;
    }


    /**
    * Get all BeeWidget fields
    *
    * @return object Fields
    */
    public function getFields()
    {
        return (object) $this->fields;
    }


    /**
    * Get all BeeWidget data
    *
    * @return object Data
    */
    public function getData()
    {
        return (object) $this->data;
    }

} // End of Class

