<?php

add_action( 'bee_breadcrumbs', 'bee_breadcrumbs' );

/**
* Get breadcrumbs for current object
*
* @hooked bee_breadcrumbs
* @return void
*/
function bee_breadcrumbs()
{
    if( bee_woocommerce_check() ) {
//         add_filter( 'woocommerce_breadcrumb_defaults', '\Webit\Breadcrumbs\woocommerce_breadcrumbs' );
        woocommerce_breadcrumb();
        return;
    }

    $type = bee_breadcrumbs_type();
    $func = 'bee_breadcrumbs_type_' . $type;

    $links = array();
    $links[] = array(
        'name' => 'Home',
        'url' => get_home_url(),
        'type' => 'root',
    );

    if( function_exists( $func ) ) {
        $links = apply_filters( 'bee_breadcrumbs_links', call_user_func( $func, $links ) );
    }

    include BEE_PATH . 'templates/breadcrumbs.php';
}

/**
* Process single
*
* @return string $type
*/
function bee_breadcrumbs_type_single( $links )
{
    $post_type = get_post_type();
    $taxonomies = apply_filters( 'bee_breadcrumbs_taxonomies_for_' . $post_type, get_object_taxonomies( $post_type ) );

    if( $archive_url = get_post_type_archive_link( $post_type ) ) {
        $post_type_object = get_post_type_object( $post_type );
        $links[] = array(
            'name' => $post_type_object->label,
            'url' => $archive_url,
            'type' => $post_type,
        );
    }

    if( $taxonomies && ( $terms = wp_get_post_terms( get_the_ID(), $taxonomies ) ) ) {
        if( count($terms) > 1 ) {
            $links = array_merge( $links, array( bee_breadcrumbs_cats_sibling($terms) ) );
        }
        else {
            $links = array_merge( $links, bee_breadcrumbs_cats( $terms[0]->term_id, $terms[0]->taxonomy ) );
        }
    }

    if( $parent_id =  wp_get_post_parent_id( get_the_ID() ) ) {
        $links = array_merge( $links, bee_breadcrumbs_parent( $parent_id ) );
    }

    $links[] = array(
        'name' => apply_filters( 'bee_breadcrumbs_title_for_' . $post_type, get_the_title(), get_the_ID() ),
        'url' => get_permalink( get_the_ID() ),
        'type' => $post_type,
    );

    return $links;
}

/**
* Process list ( taxonomy, category, terms )
*
* @return string $type
*/
function bee_breadcrumbs_type_list( $links )
{
    $current = get_queried_object();

    global $wp_taxonomies;
    $post_type = ( isset( $wp_taxonomies[$current->taxonomy] ) ) ? $wp_taxonomies[$current->taxonomy]->object_type : array();
    $post_type = reset( $post_type );

    $post_type_object = get_post_type_object( $post_type );
    $links[] = array(
        'name' => $post_type_object->label,
        'url' => get_post_type_archive_link( $post_type ),
        'type' => $post_type,
    );

    $links = array_merge( $links, bee_breadcrumbs_cats( $current->term_id, $current->taxonomy ) );

    return $links;
}

/**
* Process archive
*
* @return string $type
*/
function bee_breadcrumbs_type_archive( $links )
{
    $current = get_queried_object();

    $links[] = array(
        'name' => $current->label,
        'url' => get_post_type_archive_link( $current->name ),
        'type' => 'archive',
    );

    return $links;
}


/**
* Process blog
*
* @return string $type
*/
function bee_breadcrumbs_type_blog( $links )
{
    $post_type = get_post_type();

    if( $archive_url = get_post_type_archive_link( $post_type ) ) {
        $post_type_object = get_post_type_object( $post_type );
        $links[] = array(
            'name' => $post_type_object->label,
            'url' => $archive_url,
            'type' => $post_type,
        );
    }

    return $links;
}


/**
* Process 404
*
* @return string $type
*/
function bee_breadcrumbs_type_404( $links )
{
    $links[] = array(
        'name' => 'Page not found',
        'url' => get_home_url(),
        'type' => '404',
    );

    return $links;
}


/**
* Process search
*
* @return string $type
*/
function bee_breadcrumbs_type_search( $links )
{
    $links[] = array(
        'name' => 'Search results',
        'url' => get_home_url(),
        'type' => 'search',
    );

    return $links;
}


/**
* Get parent pages
*
* @param int $post_id
* @return array $links
*/
function bee_breadcrumbs_parent( $id )
{
    $current = get_post( $id );
    $links = array();

    if( $current->post_parent ) {
        $links = array_merge( $links, bee_breadcrumbs_parent( $current->post_parent ) );
    }

    $links[] = array(
        'name' => $current->post_title,
        'url' => get_permalink( $id ),
        'type' => $current->post_type,
    );

    return $links;
}

/**
* Recursive function for getting categories
*
* @return array $chain
*/
function bee_breadcrumbs_cats( $id, $taxonomy='category' )
{
    $chain = array();
    $parent = get_term( $id, $taxonomy );

    if ( is_wp_error( $parent ) )
        return array();

    $name = $parent->name;

    if ( $parent->parent && ( $parent->parent != $parent->term_id ) ) {
        $chain = array_merge($chain, bee_breadcrumbs_cats( $parent->parent, $taxonomy ));
    }

    $current = array(
        'name' => $parent->name,
        'url' => get_term_link( $parent->term_id, $taxonomy ),
        'type' => $taxonomy,
    );

    $chain = array_merge( $chain, array( $current ) );

    return $chain;
}


/**
* Get category siblings
*
* @return array $links
*/
function bee_breadcrumbs_cats_sibling( $cats, $taxonomy='category' )
{
    $links = array();
    foreach( $cats as $cat ) {
        $links[] = array(
            'name' => $cat->name,
            'url' => get_term_link($cat),
            'type' => $taxonomy,
        );
    }

    return $links;
}


/**
* Determine breadcrumb type
*
* @return string $type
*/
function bee_breadcrumbs_type()
{
    $type = 'unknown';

    if ( is_front_page() && is_home() ) {
        $type = 'home_list';
    }
    elseif ( is_front_page() ) {
        $type = 'home_page';
    }
    elseif ( is_home() ) {
        $type = 'blog';
    }
    elseif( is_single() || is_page() || is_singular() ) {
        $type = 'single';
    }
    elseif( is_category() || is_tax() || is_tag() ) {
        $type = 'list';
    }
    elseif( is_archive() || is_post_type_archive() ) {
        $type = 'archive';
    }
    elseif( is_404() ) {
        $type = '404';
    }
    elseif( is_search() ) {
        $type = 'search';
    }

    return $type;
}