<?php

### Move scripts to footer
add_action( 'wp_enqueue_scripts', 'hooks_move_scripts_to_footer', 999888 );

### Remove things from header
add_action( 'after_setup_theme', 'hooks_remove_api' );

### Add body class - slug
add_filter( 'body_class', 'hooks_body_class' );

### Minify content
// add_filter( 'bee_minify', 'hooks_minify' );

### Remove ver from GET params for css/js
add_filter( 'style_loader_src', 'hooks_remove_wp_ver_css_js', 999888 );
add_filter( 'script_loader_src', 'hooks_remove_wp_ver_css_js', 999888 );

### Dashboard
add_action( 'wp_dashboard_setup', 'hooks_remove_dashboard_widgets' );

/**
* Move scripts from header to footer for better performance
*
* @return void
*/
function hooks_move_scripts_to_footer()
{
   remove_action( 'wp_head', 'wp_print_scripts' );
   remove_action( 'wp_head', 'wp_print_head_scripts', 9 );
   remove_action( 'wp_head', 'wp_enqueue_scripts', 1 );

   add_action( 'wp_footer', 'wp_print_scripts', 5 );
   add_action( 'wp_footer', 'wp_enqueue_scripts', 5 );
   add_action( 'wp_footer', 'wp_print_head_scripts', 5 );
}


/**
* Remove bloat
*
* @return void
*/
function hooks_remove_api()
{
    remove_action( 'wp_head', 'rest_output_link_wp_head', 10 );
    remove_action( 'wp_head', 'wp_oembed_add_discovery_links', 10 );
    remove_action( 'wp_head', 'wp_generator' );
    remove_action( 'wp_head', 'wp_shortlink_wp_head' );
    remove_action( 'wp_head', 'wlwmanifest_link' );
    remove_action( 'wp_head', 'rsd_link' );

  # Remove emojis bloat
    remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
    remove_action( 'wp_print_styles', 'print_emoji_styles' );
    remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
    remove_action( 'admin_print_styles', 'print_emoji_styles' );
}


/**
* Add body class
*
* @hooked body_class
* @return array $classes
*/
function hooks_body_class( $classes )
{
    if( is_singular() ) {
        $queried = get_queried_object();
        $classes[] = 'slug-' . $queried->post_name;
    }

    return $classes;
}


/**
* Minify text ( html )
*
* @hooked bee_minify
* @param string $text
* @return string
*/
function hooks_minify( $text )
{
    if( is_admin() ) {
        return $text;
    }

    $text = preg_replace( '/\r*\n+/m', "\n", $text );
    $text = preg_replace( '/\t|\s\s\s+/m', '', $text );

    return $text;
}


/**
* Remoe param ver from GET params for css/js
*
* @hooked style_loader_src script_loader_src
* @param string $src
* @return array
*/
function hooks_remove_wp_ver_css_js( $src )
{
    if ( strpos( $src, 'ver=' . get_bloginfo( 'version' ) ) ) {
        $src = remove_query_arg( 'ver', $src );
    }

    return $src;
}


function hooks_remove_dashboard_widgets ()
{
  remove_meta_box( 'dashboard_quick_press','dashboard', 'side' ); //Quick Press widget
  remove_meta_box( 'dashboard_recent_drafts', 'dashboard', 'side' ); //Recent Drafts
  remove_meta_box( 'dashboard_primary', 'dashboard', 'side' ); //WordPress.com Blog
  remove_meta_box( 'dashboard_secondary', 'dashboard', 'side' ); //Other WordPress News
  remove_meta_box( 'dashboard_incoming_links', 'dashboard', 'normal' ); //Incoming Links
//   remove_meta_box( 'dashboard_plugins', 'dashboard', 'normal' ); //Plugins
//   remove_meta_box( 'dashboard_right_now', 'dashboard', 'normal' ); //Right Now
//   remove_meta_box( 'rg_forms_dashboard', 'dashboard', 'normal' ); //Gravity Forms
  remove_meta_box( 'dashboard_recent_comments', 'dashboard','normal' ); //Recent Comments
  remove_meta_box( 'icl_dashboard_widget', 'dashboard','normal' ); //Multi Language Plugin
//   remove_meta_box( 'dashboard_activity', 'dashboard', 'normal' ); //Activity
  remove_action( 'welcome_panel', 'wp_welcome_panel' );
}

